#!/usr/bin/env python3
"""
InvMan
"""

# Imports
from flask import Flask, request, jsonify, abort
from flask_api import status

import storage

app = Flask(__name__)  # app is the Flask app


@app.route("/<location>/api/v1/items", methods = ["GET"])
def api_items(location):
    try:
        items = storage.get_items(location)
        print("Got items at {0}".format(location))
        return jsonify(items)
    except KeyError:
        print("KeyError, returning 404")
        return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND


@app.route("/<location>/api/v1/item/<item>", methods = ["GET", "DELETE"])
def api_get_item(location, item):
    if request.method == "GET":
        try:
            itemresp = storage.get_items(location)[item.lower()]
            print("Got {0}".format(item))
            return jsonify(itemresp)
        except KeyError:
            print("KeyError, returning 404")
            return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND

    elif request.method == "DELETE":
        try:
            storage.rm_item(location, item)
            print("Delete item {0} at {1}".format(item, location))
            return jsonify({'status': 'success'})
        except KeyError:
            print("KeyError, returning 404")
            return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND


@app.route("/<location>/api/v1/item/<item>/<brand>", methods = ["GET", "DELETE"])
def api_item_brand(location, item, brand):
    if request.method == "GET":
        try:
            itemresp = storage.get_items(location)[item.lower()][brand.lower()]
            print("Got {0} of brand {1} at {2}".format(item, brand, location))
            return jsonify(itemresp)
        except KeyError:
            print("KeyError, returning 404")
            return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND

    elif request.method == "DELETE":
        try:
            storage.rm_brand(location, item, brand)
            print("Deleted {0} of brand {1} at {2}".format(item, brand, location))
            return jsonify({'status': 'success'})
        except KeyError:
            print("KeyError, returning 404")
            return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND


@app.route("/<location>/api/v1/item/<item>/<brand>/<key>", methods = ["DELETE"])
def api_rm_brand_key(location, item, brand, key):
    try:
        storage.rm_brand_key(location, item, brand, key)
        print("Deleted key {0} from brand {1} of item {2} at {3}".format(key, brand, item, location))
        return jsonify({'status': 'success'})
    except KeyError:
        print("KeyError, returning 404")
        return jsonify({'status': 'error', 'error': 'NOT_FOUND'}), status.HTTP_404_NOT_FOUND


if __name__ == "__main__":
    print("Run with `flask` or a WSGI server!")
